pub fn parser_for_path(path: &Path) -> Option<Box<dyn LanguageParser>>Expand description
Return the appropriate parser for path, keyed on file extension.
Returns None when the extension is unsupported.
pub fn parser_for_path(path: &Path) -> Option<Box<dyn LanguageParser>>Return the appropriate parser for path, keyed on file extension.
Returns None when the extension is unsupported.